/****************************************************************************
**
** Compatibility file - should only be included by legacy code.
** It #includes the file which obsoletes this one.
**
** Copyright (C) 1998-2008 Trolltech ASA.  All rights reserved.
**  This file is part of the TQt GUI Toolkit.
**
** This file may be distributed under the terms of the Q Public License
** as defined by Trolltech ASA of Norway and appearing in the file
** LICENSE.TQPL included in the packaging of this file.
**
** Licensees holding valid TQt Professional Edition licenses may use this
** file in accordance with the TQt Professional Edition License Agreement
** provided with the TQt Professional Edition.
**
** See http://www.trolltech.com/pricing.html or email sales@trolltech.com for
** information about the Professional Edition licensing, or see
** http://www.trolltech.com/qpl/ for TQPL licensing information.
**
*****************************************************************************/
#ifndef TQQUEUE_H
#define TQQUEUE_H
#ifndef TQT_NO_COMPAT
#include "ntqptrqueue.h"
#endif
#endif
